module HROOT.Graf.TCanvas
       (TCanvas(..), ITCanvas(..), upcastTCanvas, downcastTCanvas,
        newTCanvas)
       where
import HROOT.Graf.TCanvas.RawType
import HROOT.Graf.TCanvas.Interface
import HROOT.Graf.TCanvas.Implementation
